"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.transform = exports.allowedDestinations = exports.getContentType = exports.getContentTypeFromExtension = void 0;
const rdf_parse_1 = __importStar(require("rdf-parse"));
const rdf_serialize_1 = __importStar(require("rdf-serialize"));
const CONTENT_MAPPINGS = {
    ...rdf_parse_1.RdfParser.CONTENT_MAPPINGS,
    ...rdf_serialize_1.RdfSerializer.CONTENT_MAPPINGS,
    ttl: 'text/turtle',
    turtle: 'text/turtle',
    shaclc: 'text/shaclc',
    shc: 'text/shaclc',
    shaclce: 'text/shaclc-ext',
    shce: 'text/shaclc-ext',
    nt: 'application/n-triples',
    ntriples: 'application/n-triples',
    nq: 'application/n-quads',
    nquads: 'application/n-quads',
    rdf: 'application/rdf+xml',
    rdfxml: 'application/rdf+xml',
    owl: 'application/rdf+xml',
    n3: 'text/n3',
    trig: 'application/trig',
    jsonld: 'application/ld+json',
    json: 'application/json',
    html: 'text/html',
    htm: 'text/html',
    xhtml: 'application/xhtml+xml',
    xht: 'application/xhtml+xml',
    xml: 'application/xml',
    svg: 'image/svg+xml',
    svgz: 'image/svg+xml',
};
const subsets = {
    'application/n-triples': new Set([
        'text/turtle',
        'text/n3',
        'application/n-quads',
    ]),
    'text/turtle': new Set(['text/n3']),
    'text/shaclc': new Set(['text/shaclc-ext']),
};
function getContentTypeFromExtension(path) {
    const dotIndex = path.lastIndexOf('.');
    if (dotIndex >= 0) {
        return CONTENT_MAPPINGS[path.substring(dotIndex + 1)] || '';
    }
    return '';
}
exports.getContentTypeFromExtension = getContentTypeFromExtension;
function getContentType(options) {
    return 'contentType' in options
        ? options.contentType
        : getContentTypeFromExtension(options.path);
}
exports.getContentType = getContentType;
// Get the content types that we are able to transform *to* from a given content-type source
async function allowedDestinations(contentType, forceTransform) {
    var _a;
    // If a transformation is forced then we are limited to the content types we can serialize to
    if (forceTransform)
        return rdf_serialize_1.default.getContentTypes();
    // If we are not forcing transformations then we can also include the current content type
    // and all supersets of that content type
    return [
        ...new Set([
            contentType,
            ...((_a = subsets[contentType]) !== null && _a !== void 0 ? _a : []),
            ...(await rdf_serialize_1.default.getContentTypes()),
        ]),
    ];
}
exports.allowedDestinations = allowedDestinations;
function transform(stream, options) {
    var _a;
    const from = getContentType(options.from);
    const to = getContentType(options.to);
    // If transformations are not forced,
    // and we are transforming to a content-type that is the same as, or a
    // subset of the source, then just return the original stream
    if (!options.forceTransform) {
        if (from === to || ((_a = subsets[from]) === null || _a === void 0 ? void 0 : _a.has(to)))
            return stream;
    }
    return rdf_serialize_1.default.serialize(rdf_parse_1.default.parse(stream, { baseIRI: options.baseIRI, contentType: from }), { contentType: to });
}
exports.transform = transform;
